@@ -1,8 +1,13 @@
+import os
 import random
 from typing import Optional, Tuple
 
 import panel as pn
 
+api_base_url = os.getenv("DB_URL")
+student_user = os.getenv("user_name_student")
+student_pw = os.getenv("keys_student")
+
 
 def list_of_lists(options: list) -> bool:
     return all(isinstance(elem, list) for elem in options)
@@ -10,7 +15,9 @@ def list_of_lists(options: list) -> bool:
 
 def shuffle_options(options: list[Optional[str]], seed: int) -> list[Optional[str]]:
     random.seed(seed)
-    random.shuffle(options)
+    
+    for inner_list in options:
+        random.shuffle(inner_list)
 
     return options
 
